@@ -2,14 +2,9 @@ package RDF::RDFa::Generator::HTML::Hidden;
 
 use 5.008;
 use base qw'RDF::RDFa::Generator::HTML::Head';
-use strict;
+use common::sense;
 use XML::LibXML qw':all';
 
-use warnings;
-
-
-our $VERSION = '0.199_06';
-
 sub injection_site
 {
 	return '//xhtml:body';
@@ -27,12 +22,13 @@ sub nodes
 	$rootnode->setNamespace('http://www.w3.org/1999/xhtml', undef, 1);
 	$rootnode->setAttribute('style','display:none');
 	
+	my $prefixes = {};
 	my $subjects = {};
 	while (my $st = $stream->next)
 	{
 		my $s = $st->subject->is_resource ?
-			$st->subject->abs :
-			('_:'.$st->subject->value);
+			$st->subject->uri :
+			('_:'.$st->subject->blank_identifier);
 		push @{ $subjects->{$s} }, $st;
 	}
 	
@@ -40,25 +36,35 @@ sub nodes
 	{
 		my $node = $rootnode->addNewChild('http://www.w3.org/1999/xhtml', 'i');
 		
-		$self->_process_subject($subjects->{$s}->[0], $node);
+		$self->_process_subject($subjects->{$s}->[0], $node, $prefixes);
 		
 		foreach my $st (@{ $subjects->{$s} })
 		{
 			my $node2 = $node->addNewChild('http://www.w3.org/1999/xhtml', 'i');
-			$self->_process_predicate($st, $node2)
-			     ->_process_object($st, $node2);
+			$self->_process_predicate($st, $node2, $prefixes)
+			     ->_process_object($st, $node2, $prefixes);
 		}
 	}
 	
-	if (defined($self->{'version'}) && $self->{'version'} == 1.1
-		 and $self->{'prefix_attr'}) {
-	  if (defined($self->{namespacemap}->rdfa)) {
-		 $rootnode->setAttribute('prefix', $self->{namespacemap}->rdfa->as_string);
-	  }
-	} else {
-	  while (my ($prefix, $nsURI) = $self->{namespacemap}->each_map) {
-		 $rootnode->setNamespace($nsURI->as_string, $prefix, 0);
-	  }
+	if ($self->{'version'} == 1.1
+	and $self->{'prefix_attr'})
+	{
+		my $prefix_string = '';
+		while (my ($u,$p) = each(%$prefixes))
+		{
+			$prefix_string .= sprintf("%s: %s ", $p, $u);
+		}
+		if (length $prefix_string)
+		{
+			$rootnode->setAttribute('prefix', $prefix_string);
+		}
+	}
+	else
+	{
+		while (my ($u,$p) = each(%$prefixes))
+		{
+			$rootnode->setNamespace($u, $p, 0);
+		}
 	}
 	
 	push @nodes, $rootnode;
@@ -72,16 +78,16 @@ sub nodes
 
 sub _process_subject
 {
-	my ($self, $st, $node) = @_;
+	my ($self, $st, $node, $prefixes) = @_;
 	
 	if (defined $self->{'base'} 
 	and $st->subject->is_resource
-	and $st->subject->abs eq $self->{'base'})
-		{ $node->setAttribute('about', ''); }
+	and $st->subject->uri eq $self->{'base'})
+		{ $node->setAttribute('src', ''); }
 	elsif ($st->subject->is_resource) 
-		{ $node->setAttribute('about', $st->subject->abs); }
+		{ $node->setAttribute('src', $st->subject->uri); }
 	else
-		{ $node->setAttribute('about', '[_:'.$st->subject->value.']'); }
+		{ $node->setAttribute('about', '[_:'.$st->subject->blank_identifier.']'); }
 	
 	return $self;
 }
